@@ -15,14 +15,12 @@ def intercept_worker(fn, *args, **kwargs):
 
     try:
         callback = fn(*args, **kwargs)
-        ctx = TraceContextManager.getLocalContext()
         return callback
     except Exception as e:
         interceptor_step_error(e)
         raise e
     finally:
-        if ctx:
-            end_interceptor(ctx=ctx)
+        end_interceptor()
 
 def instrument_nameko_spawn_worker(module):
     def wrapper(fn):
@@ -34,5 +32,7 @@ def instrument_nameko_spawn_worker(module):
         return trace
 
     if hasattr(module, 'ServiceContainer') and hasattr(module.ServiceContainer, '_run_worker'):
+        from eventlet.corolocal import local
+        TraceContextManager.local = local()
         module.ServiceContainer._run_worker = wrapper(module.ServiceContainer._run_worker)
 
