@@ -29,6 +29,12 @@ def isEventlet():
     else:
         return False
 
+def sendDebugProfile(ctx, msg):
+    if ctx:
+        ctx.elapsed = 0
+        datas = [' ', ' ', 'DEBUG: ' + msg]
+        UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+
 def trace_handler(fn, start=False):
     def handler(func):
         @wraps(func)
@@ -144,7 +150,7 @@ def interceptor(rn_environ, *args, **kwargs):
     start_interceptor(ctx)
     
     callback = fn(*args, **kwargs)
-
+    ctx = TraceContextManager.getLocalContext()
     if ctx:
         query_string = environ.get('QUERY_STRING', '')
         if query_string:
@@ -263,6 +269,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         interceptor_step_error(e)
         print('interceptor_httpc_request', e)
     finally:
+        ctx = TraceContextManager.getLocalContext()
         datas = [ctx.httpc_url, ctx.mcallee]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         UdpSession.send_packet(PacketTypeEnum.TX_HTTPC, ctx, datas)
@@ -313,7 +320,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     if not kwargs:
         kwargs = dict(
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
-    
+    ctx = TraceContextManager.getLocalContext()
     text = '{}://'.format(db_type)
     text += kwargs.get('user')
     text += "@"
@@ -345,6 +352,7 @@ def addQuote(arg_dict):
 def interceptor_db_execute(fn, *args, **kwargs):
     # print('interceptor_db_execute step -1')
     ctx = TraceContextManager.getLocalContext()
+    #sendDebugProfile(ctx, 'interceptor_db_execute step -1')
     # print('interceptor_db_execute step -2 ctx:', ctx)
     self = args[0]
     query = None
@@ -378,6 +386,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
         interceptor_step_error(e)
     finally:
         # print('interceptor_db_execute step -7 txid:', ctx.id)
+        ctx = TraceContextManager.getLocalContext()
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
